==> libddog-0.1.3.tar.gz: libddog-0.1.3/docs/FEATURE_SUPPORT.md <==
# Datadog feature support


## Dashboards

| Type        | Supported?         | Comments |
|-------------|--------------------|----------|
| Dashboard   | :heavy_check_mark: | :100:    |
| Timeboard   | :x:                |          |
| Screenboard | :x:                |          |


## Widgets

| Type            | Supported?         | Comments               |
|-----------------|--------------------|------------------------|
| Group           | :heavy_check_mark: | Does not support image |
| Note            | :heavy_check_mark: | :100:                  |
| Timeseries      | :heavy_check_mark: | :100:                  |
| Query Value     | :heavy_check_mark: | :100:                  |
| Table           | :x:                |                        |
| Top List        | :x:                |                        |
| SLO Summary     | :x:                |                        |
| Heat Map        | :x:                |                        |
| Check Status    | :x:                |                        |
| Change          | :x:                |                        |
| Host Map        | :x:                |                        |
| Image           | :x:                |                        |
| Event Stream    | :x:                |                        |
| Event Timeline  | :x:                |                        |
| Scatter Plot    | :x:                |                        |
| Distribution    | :x:                |                        |
| Free Text       | :x:                |                        |
| IFrame          | :x:                |                        |
| Monitor Summary | :x:                |                        |
| Alert Graph     | :x:                |                        |
| Alert Value     | :x:                |                        |
| Log Stream      | :x:                |                        |
| Service Summary | :x:                |                        |
| Geomap          | :x:                |                        |
| List            | :x:                |                        |

==> libddog-0.1.8.post1.tar.gz: libddog-0.1.8.post1/docs/FEATURE_SUPPORT.md <==
# Datadog feature support


## Dashboards

| Type        | Supported?         | Comments |
|-------------|--------------------|----------|
| Dashboard   | :heavy_check_mark: | :100:    |
| Timeboard   | :x:                |          |
| Screenboard | :x:                |          |


## Widgets

| Type            | Supported?         | Comments               |
|-----------------|--------------------|------------------------|
| Group           | :heavy_check_mark: | Does not support image |
| Note            | :heavy_check_mark: | :100:                  |
| Timeseries      | :heavy_check_mark: | :100:                  |
| Query Value     | :heavy_check_mark: | :100:                  |
| Table           | :x:                |                        |
| Top List        | :heavy_check_mark: | :100:                  |
| SLO Summary     | :x:                |                        |
| Heat Map        | :x:                |                        |
| Check Status    | :x:                |                        |
| Change          | :x:                |                        |
| Host Map        | :x:                |                        |
| Image           | :x:                |                        |
| Event Stream    | :x:                |                        |
| Event Timeline  | :x:                |                        |
| Scatter Plot    | :x:                |                        |
| Distribution    | :x:                |                        |
| Free Text       | :x:                |                        |
| IFrame          | :x:                |                        |
| Monitor Summary | :x:                |                        |
| Alert Graph     | :x:                |                        |
| Alert Value     | :x:                |                        |
| Log Stream      | :x:                |                        |
| Service Summary | :x:                |                        |
| Geomap          | :x:                |                        |
| List            | :x:                |                        |
